@@ -1,6 +1,6 @@
 package arcos;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.12;
+use rancid 3.13;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -152,26 +152,6 @@ sub ShowVersion {
     ProcessHistory("COMMENTS","keysort","VERSION","!\n");
     return(0);
 }
-# This routine parses "show features"
-sub ShowFeatures {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowVersion: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	last if (/^$prompt/);
-	next if (/^\s+\^$/);
-	return(1) if (/Line has invalid autocommand /);
-	return(1) if (/(invalid (input|command) detected|type help or )/i);
-	return(-1) if (/command authorization failed/i);
-	return(-1) if (/error: application communication failure/i);
-
-	ProcessHistory("","","","! $_");
-    }
-    ProcessHistory("","","","!\n");
-    return(0);
-}
 
 # This routine parses "show hardware"
 sub ShowHardware {
