@@ -1,6 +1,6 @@
 package ios;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.12;
+use rancid 3.13;
 
 our $proc;
 our $ios;
@@ -605,6 +605,7 @@ sub ShowLicense {
 	return(0) if (/% incomplete command/i);                 # show lic on old XE box
 	return(1) if (/Line has invalid autocommand /);
 	return(1) if (/(invalid (input|command) detected|type help or )/i);
+	return(-1) if (/(?:%|command)? authorization failed/i);
 	return(-1) if (/unable to retrieve license info/i);
 
 	# filter the BS from license broker
@@ -1092,7 +1093,7 @@ sub ShowFlash {
 	/\s+(private-multiple-fs|multiple-fs|LISP-MapCache-IPv\S+|nv_hdr)$/ &&
 	    next;
 
-	if (/(dhcp_[^. ]*\.txt|vlan\.dat|sflog|snooping)/ ||
+	if (/(dhcp_[^. ]*\.txt|license_evlog|vlan\.dat|sflog|snooping)/ ||
 		 /(LOCAL-CA-SERVER(?:[^\s]*))\s*$/ ||
 		 /(smart-log\/agentlog|syslog)\s*$/ ||
 		 /(log\/(?:ssp_tz\/)?[^. ]+\.log(?:\.[0-9]+\.gz)?)\s*$/) {
@@ -1386,11 +1387,11 @@ sub ShowContAll {
 	    ProcessHistory("INT","","","!Interface: $1\n") && next;
 	/(Media Type is \S+),/ &&
 	    ProcessHistory("INT","","","!\t$1\n");
-	    if (/(M\dT[^ :]*:) show controller:$/) {
-		my($ctlr) = $1;
-		$_ = <$INPUT>; tr/\015//d; s/ subunit \d,//;
-		ProcessHistory("INT","","","!Interface: $ctlr $_");
-	    }
+	if (/(M\dT[^ :]*:) show controller:$/) {
+	    my($ctlr) = $1;
+	    $_ = <$INPUT>; tr/\015//d; s/ subunit \d,//;
+	    ProcessHistory("INT","","","!Interface: $ctlr $_");
+	}
 	if (/^(\S+) : show controller:$/) {
 	    my($ctlr) = $1;
 	    $_ = <$INPUT>; tr/\015//d; s/ subunit \d,//;
@@ -1500,6 +1501,8 @@ sub ShowDebug {
 	return(1) if (/Line has invalid autocommand /);
 	return(1) if (/(invalid (input|command) detected|type help or )/i);
 	return(-1) if (/(?:%|command)? authorization failed/i);
+	# ASAv produce this error occasionally
+	return(-1) if (/unable to retrieve licensing debug info/i);
 	# the pager can not be disabled per-session on the PIX
 	if (/^(<-+ More -+>)/) {
 	    my($len) = length($1);
