@@ -1,6 +1,6 @@
 package iosxr;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.12;
+use rancid 3.13;
 
 our $proc;
 our $found_env;
@@ -543,6 +543,7 @@ sub ShowInstallActive {
 
 	ProcessHistory("COMMENTS","keysort","F5","!Image: $_") && next;
     }
+    ProcessHistory("COMMENTS","keysort","F5","!\n");
     return(0);
 }
 
@@ -613,6 +614,22 @@ sub ShowEnv {
 	    }
 	    next;
 	}
+	if (/power shelf \d+:/i) {
+	    my($sep) = 0;
+	    ProcessHistory("COMMENTS","keysort","E1","!Power: $_");
+	    while (<$INPUT>) {
+		tr/\015//d;
+		goto OUT if (/^$prompt/);
+		last if (/^altitude information/i);
+		last if (/^=+$/i && ($sep > 1));
+		$sep++ if (/^=+$/i);
+		if (/^(\s+\S+\s+\S+-(?:AC|DC)\s+)(\S+\s+\S+\s+\S+\s+\S+)(\s+.*)/) {
+		    $_ = sprintf("%s%-". length($2) ."s%s\n", $1, "", $3);
+		}
+		ProcessHistory("COMMENTS","keysort","E1","!Power: $_");
+	    }
+	    next;
+	}
 	/^Power Supply Information$/ && next;
 	/^\s*Power Module\s+Voltage\s+Current$/ && next;
 	/^\s*(Power [^:\n]+)$/ &&
@@ -625,7 +642,7 @@ sub ShowEnv {
 	    ProcessHistory("COMMENTS","keysort","E2","!Power: $1\n") && next;
     }
 OUT:
-    ProcessHistory("COMMENTS","","","!\n");
+    ProcessHistory("COMMENTS","keysort","E3","!\n");
     return(0);
 }
 
