@@ -1,6 +1,6 @@
 package junos;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -56,7 +56,7 @@ require(Exporter);
 our @ISA = qw(Exporter);
 $Exporter::Verbose=1;
 
-use rancid 3.12;
+use rancid 3.13;
 
 our $ShowChassisSCB;			# Only run ShowChassisSCB() once
 our $ShowChassisFirmware;		# Only run ShowChassisFirmware() once
@@ -596,7 +596,7 @@ sub ShowVersion {
 	next if (/^system (shutdown message from|going down )/i);
 	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
 	/error: abnormal communication termination with / && return(-1);
-	/error: could not connect to \S+ : no route to host/i && return(-1);
+	/error: could not connect to \S+ ?: no route to host/i && return(1);
 
 	/warning: .* subsystem not running - not needed by configuration/ && next;
 
