@@ -1,6 +1,6 @@
 package nxos;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.12;
+use rancid 3.13;
 
 our $proc;
 our $type;				# device model, from ShowVersion
@@ -585,8 +585,23 @@ sub ShowModule {
 	s/(.*) \*$/$1/;	# Drop a trailing '*'
 	/^\* this terminal session/ && next;
 	s/ +$//;	# Drop trailing ' '
+
+	# filter fluctuating WWNs
+	if (/\s+World-Wide-Name.*/i) {
+	    ProcessHistory("COMMENTS","","","!Mod: $_");
+	    while (<$INPUT>) {
+		tr/\015//d;
+		goto EndShowModule if (/^$prompt/);
+		last if (/^\s*$/);
+		if (/^(\d+\s+\S+\s+\S+)\s+.*$/) {
+		    $_ = sprintf("%s\n", $1);
+		}
+		ProcessHistory("COMMENTS","","","!Mod: $_");
+	    }
+	}
 	ProcessHistory("COMMENTS","","","!Mod: $_");
     }
+EndShowModule:
     ProcessHistory("COMMENTS","","","!\n");
 
     return(0);
