@@ -1,6 +1,6 @@
 package rancid;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -99,7 +99,7 @@ our @EXPORT = qw($VERSION $devtype $script $lscript @modules $inloop
 		RunCommand sortbyipaddr valsort which);
 
 BEGIN {
-    $VERSION = '3.12';
+    $VERSION = '3.13';
 }
 
 # initialize common rancid parameters and handle command-line arguments.
@@ -107,7 +107,7 @@ sub rancidinit {
     my($i);
 
     if ($main::opt_V) {
-	print "rancid 3.12\n";
+	print "rancid 3.13\n";
 	exit(0);
     }
 
@@ -119,7 +119,6 @@ sub rancidinit {
 
     $log = $main::opt_l;
     $debug = $main::opt_d;
-    $devtype = lc($main::opt_t);
     $file = $main::opt_f;
     $host = defined($ARGV[0]) ? $ARGV[0] : "";
     $clean_run = 0;
@@ -176,6 +175,7 @@ sub rancidinit {
 	print(STDERR "Too few arguments: -t option is required\n");
 	exit(1);
     }
+    $devtype = lc($main::opt_t);
 
     # make OUTPUT unbuffered if debugging
     if ($debug) { $| = 1; }
@@ -208,7 +208,15 @@ sub loadtype {
 	    $line++;
 	    chomp;
 	    next if (/^\s*$/ || /^\s*#/);
-	    my($type, $directive, $value, $value2) = split('\;');
+	    my(@line) = split('\;');
+	    # check number of fields
+	    if (($#line + 1) < 3) {
+		printf(STDERR
+		       "loadtype: insufficient number of fields $#line at %s:%d\n",
+		       $file, $line);
+		return(-1);
+	    }
+	    my($type, $directive, $value) = @line;
 	    $type =~ tr/[A-Z]/[a-z]/;
 	    $directive =~ tr/[A-Z]/[a-z]/;
 
@@ -252,7 +260,13 @@ sub loadtype {
 	    } elsif ($directive eq "inloop") {
 		$inloop = $value;
 	    } elsif ($directive eq "command") {
-		push(@commandtable, {$value2, $value});
+		if (($#line + 1) < 4) {
+		    printf(STDERR
+			"loadtype: insufficient number of fields at %s:%d\n",
+			$file, $line);
+		    return(-1);
+		}
+		push(@commandtable, {$line[3], $value});
 	    } elsif ($directive eq "timeout") {
 		$timeo = $value;
 	    } else {
