@@ -1,6 +1,6 @@
 package sros;
 ##
-## rancid 3.12
+## rancid 3.13
 ## Copyright (c) 1997-2019 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
@@ -55,7 +55,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.12;
+use rancid 3.13;
 
 our $proc;
 our $memoryseen;
@@ -534,6 +534,7 @@ sub WriteTermMD {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In WriteTermMD: $_" if ($debug);
     ProcessHistory("","","","#\n# $_");
+    my($linecnt) = 0;
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -542,8 +543,6 @@ sub WriteTermMD {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
 	/# Generated /i && next;
@@ -551,6 +550,8 @@ sub WriteTermMD {
 	/^#-+$/i && next;
 	s/echo \"(.*)\"/# $1/i;
 
+	$linecnt++;
+
 	# password/community filtering
 	if (/^(\s+community) "[^"]*" /) {
 	    if ($filter_commstr) {
@@ -576,7 +577,7 @@ sub WriteTermMD {
 	}
 
 	# end of config.
-	if (/^# finished \S{3} \S{3} /i) {
+	if ((/^(# finished \S{3} \S{3} |\[\]\s*$)/i) && $linecnt > 5) {
 	    $found_end = 1;
 	    return(0);
 	}
